# eric7.Plugins.CheckerPlugins.CodeStyleChecker.Security.Checks.prohibitedCalls

Module implementing checks for prohibited methods and functions.

### Global Attributes

_prohibitedCalls

### Classes

None

### Functions

checkProhibitedCalls | Function to check for prohibited method calls.
getChecks | Public method to get a dictionary with checks handled by this module.

## checkProhibitedCalls

checkProhibitedCalls(reportError, context, _config)

Function to check for prohibited method calls.

reportError (func)
  function to be used to report errors
context (SecurityContext)
  security context object
_config (dict)
  dictionary with configuration data (unused)

Up

## getChecks

getChecks()

Public method to get a dictionary with checks handled by this module.

Return:
  dictionary containing checker lists containing checker function and list of codes

Return Type:
  dict

Up